![Test Kouyou Package](https://github.com/GutoReis/kouyou/workflows/Test%20Kouyou%20Package/badge.svg?branch=test) ![Auto Deploy Kouyou Package on PyPI](https://github.com/GutoReis/kouyou/workflows/Auto%20Deploy%20Kouyou%20Package%20on%20PyPI/badge.svg) [![codecov](https://codecov.io/gh/GutoReis/kouyou/branch/master/graph/badge.svg)](https://codecov.io/gh/GutoReis/kouyou) [![Documentation Status](https://readthedocs.org/projects/kouyou/badge/?version=latest)](https://kouyou.readthedocs.io/en/latest/?badge=latest) [![PyPI version](https://badge.fury.io/py/kouyou.svg)](https://badge.fury.io/py/kouyou) [![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT) 

![kouyou logo](https://drive.google.com/uc?export=view&id=1R9cw03Z0zUezPbeBEvVSOoWKqQg58Mvm)

# Kouyou
**Kouyou** is a japanese word meaning ***utility***, as the word itself implies, is a python package with every ***util*** code made by me, used in personal projects. Feel free to fork, make PRs with sugestion.

# TO-DO
> * Google Drive utility to update existed google sheet from a pandas.DataFrame

**Kouyou is part of the Zaidan project** (Link to Zaidan incoming)